import { Args, Command } from '@oclif/core';
import WalletService from '../../services/WalletService.js';
export default class WalletDefault extends Command {
    static args = {
        address: Args.string({ description: 'The address of the wallet to set as default.', required: true }),
    };
    static description = 'Set the default wallet for L1X.';
    static examples = [
        '<%= config.bin %> <%= command.id %> <address>',
    ];
    static flags = {
    // flag with no value (-f, --force)
    // force: Flags.boolean({char: 'f'}),
    // flag with a value (-n, --name=VALUE)
    // name: Flags.string({char: 'n', description: 'name to print'}),
    };
    async run() {
        const { args } = await this.parse(WalletDefault);
        // Validate Wallet Address
        if (!WalletService.isValidAddress(args.address)) {
            throw new Error('Invalid Wallet Address');
        }
        let defautResponse = await WalletService.setDefaultWallet(args.address);
        if (defautResponse.hasError) {
            throw new Error(defautResponse.message);
        }
        this.log(`Default Wallet set to ${args.address}`);
    }
}
